@@ -57,7 +57,8 @@
 #'   `lsf_cores = NULL` omits this line.
 crew_launcher_lsf <- function(
   name = NULL,
-  seconds_launch = 60,
+  seconds_interval = 0.25,
+  seconds_launch = 86400,
   seconds_idle = Inf,
   seconds_wall = Inf,
   seconds_exit = 1,
@@ -82,6 +83,7 @@ crew_launcher_lsf <- function(
   name <- as.character(name %|||% crew::crew_random_name())
   launcher <- crew_class_launcher_lsf$new(
     name = name,
+    seconds_interval = seconds_interval,
     seconds_launch = seconds_launch,
     seconds_idle = seconds_idle,
     seconds_wall = seconds_wall,
@@ -134,6 +136,7 @@ crew_class_launcher_lsf <- R6::R6Class(
     #' @description LSF launcher constructor.
     #' @return an LSF launcher object.
     #' @param name See [crew_launcher_lsf()].
+    #' @param seconds_interval See [crew_launcher_lsf()].
     #' @param seconds_launch See [crew_launcher_lsf()].
     #' @param seconds_idle See [crew_launcher_lsf()].
     #' @param seconds_wall See [crew_launcher_lsf()].
@@ -157,6 +160,7 @@ crew_class_launcher_lsf <- R6::R6Class(
     #' @param lsf_cores See [crew_launcher_lsf()].
     initialize = function(
       name = NULL,
+      seconds_interval = NULL,
       seconds_launch = NULL,
       seconds_idle = NULL,
       seconds_wall = NULL,
@@ -181,6 +185,7 @@ crew_class_launcher_lsf <- R6::R6Class(
     ) {
       super$initialize(
         name = name,
+        seconds_interval = seconds_interval,
         seconds_launch = seconds_launch,
         seconds_idle = seconds_idle,
         seconds_wall = seconds_wall,
@@ -252,6 +257,7 @@ crew_class_launcher_lsf <- R6::R6Class(
     #' @param name Character of length 1, name of the job. For inspection
     #'   purposes, you can supply a mock job name.
     #' @examples
+    #' if (identical(Sys.getenv("CREW_EXAMPLES"), "true")) {
     #' launcher <- crew_launcher_lsf(
     #'   lsf_cwd = getwd(),
     #'   lsf_log_output = "log_file_%J.log",
@@ -259,6 +265,7 @@ crew_class_launcher_lsf <- R6::R6Class(
     #'   lsf_memory_gigabytes_limit = 4
     #' )
     #' launcher$script(name = "my_job_name")
+    #' }
     script = function(name) {
       c(
         "#!/bin/sh",
