@@ -62,7 +62,8 @@
 #'   `pbs_walltime_hours = NULL` omits this line.
 crew_launcher_pbs <- function(
   name = NULL,
-  seconds_launch = 60,
+  seconds_interval = 0.25,
+  seconds_launch = 86400,
   seconds_idle = Inf,
   seconds_wall = Inf,
   seconds_exit = 1,
@@ -88,6 +89,7 @@ crew_launcher_pbs <- function(
   name <- as.character(name %|||% crew::crew_random_name())
   launcher <- crew_class_launcher_pbs$new(
     name = name,
+    seconds_interval = seconds_interval,
     seconds_launch = seconds_launch,
     seconds_idle = seconds_idle,
     seconds_wall = seconds_wall,
@@ -143,6 +145,7 @@ crew_class_launcher_pbs <- R6::R6Class(
     #' @description PBS/TORQUE launcher constructor.
     #' @return an PBS/TORQUE launcher object.
     #' @param name See [crew_launcher_pbs()].
+    #' @param seconds_interval See [crew_launcher_pbs()].
     #' @param seconds_launch See [crew_launcher_pbs()].
     #' @param seconds_idle See [crew_launcher_pbs()].
     #' @param seconds_wall See [crew_launcher_pbs()].
@@ -167,6 +170,7 @@ crew_class_launcher_pbs <- R6::R6Class(
     #' @param pbs_walltime_hours See [crew_launcher_pbs()].
     initialize = function(
       name = NULL,
+      seconds_interval = NULL,
       seconds_launch = NULL,
       seconds_idle = NULL,
       seconds_wall = NULL,
@@ -192,6 +196,7 @@ crew_class_launcher_pbs <- R6::R6Class(
     ) {
       super$initialize(
         name = name,
+        seconds_interval = seconds_interval,
         seconds_launch = seconds_launch,
         seconds_idle = seconds_idle,
         seconds_wall = seconds_wall,
@@ -280,11 +285,13 @@ crew_class_launcher_pbs <- R6::R6Class(
     #' @param name Character of length 1, name of the job. For inspection
     #'   purposes, you can supply a mock job name.
     #' @examples
+    #' if (identical(Sys.getenv("CREW_EXAMPLES"), "true")) {
     #' launcher <- crew_launcher_pbs(
     #'   pbs_cores = 2,
     #'   pbs_memory_gigabytes_required = 4
     #' )
     #' launcher$script(name = "my_job_name")
+    #' }
     script = function(name) {
       c(
         paste("#PBS -N", name),
