@@ -3,15 +3,19 @@ library(testthat)
 controller <- crew_controller_sge(
   name = "my_workflow",
   workers = 1L,
+  seconds_launch = 720,
   seconds_idle = 300,
-  sge_lines = paste0("module load R/", getRversion())
+  script_lines = paste0("module load R/", getRversion()),
+  verbose = TRUE
 )
 controller$start()
-controller$push(
+controller$push( # Should see a job submission message.
   name = "do work",
   command = as.character(Sys.info()["nodename"])
 )
 controller$wait()
 task <- controller$pop()
 expect_false(task$result[[1L]] == as.character(Sys.info()["nodename"]))
+controller$launcher$terminate() # Should see a job deletion message.
+Sys.sleep(5L)
 controller$terminate()
